Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(669)

Unified Diff: third_party/WebKit/Source/core/paint/PaintPropertyTreeBuilder.h

Issue 2695593005: Avoid false-positives of paint offset change detection (Closed)
Patch Set: - Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | third_party/WebKit/Source/core/paint/PaintPropertyTreeBuilder.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/Source/core/paint/PaintPropertyTreeBuilder.h
diff --git a/third_party/WebKit/Source/core/paint/PaintPropertyTreeBuilder.h b/third_party/WebKit/Source/core/paint/PaintPropertyTreeBuilder.h
index c4386dc28f16417b15beb3c673e7f263c47a8098..f5fc89141eb91aa514ada7ed437791ecd4352fe2 100644
--- a/third_party/WebKit/Source/core/paint/PaintPropertyTreeBuilder.h
+++ b/third_party/WebKit/Source/core/paint/PaintPropertyTreeBuilder.h
@@ -15,6 +15,7 @@
namespace blink {
class FrameView;
+class LayoutBoxModelObject;
class LayoutObject;
// The context for PaintPropertyTreeBuilder.
@@ -99,9 +100,9 @@ class PaintPropertyTreeBuilder {
// date.
void updateProperties(FrameView&, PaintPropertyTreeBuilderContext&);
// Update the context to account for positioning. No paint properties are
// updated but this can affect the current paint offset which will force a
// subtree update.
void updateContextForBoxPosition(const LayoutObject&,
PaintPropertyTreeBuilderContext&);
@@ -116,8 +117,10 @@ class PaintPropertyTreeBuilder {
PaintPropertyTreeBuilderContext&);
private:
+ ALWAYS_INLINE static void updatePaintOffset(const LayoutBoxModelObject&,
+ PaintPropertyTreeBuilderContext&);
ALWAYS_INLINE static void updatePaintOffsetTranslation(
- const LayoutObject&,
+ const LayoutBoxModelObject&,
PaintPropertyTreeBuilderContext&);
ALWAYS_INLINE static void updateTransform(const LayoutObject&,
PaintPropertyTreeBuilderContext&);
@@ -99,9 +100,9 @@ class PaintPropertyTreeBuilder {
// date.
void updateProperties(FrameView&, PaintPropertyTreeBuilderContext&);
- // Update the context to account for positioning. No paint properties are
- // updated but this can affect the current paint offset which will force a
- // subtree update.
+ // Update the context to account for positioning. Paint offset and
+ // paint offset translation (if needed) are updated. If paint offset changes
+ // we will force subtree update.
void updateContextForBoxPosition(const LayoutObject&,
PaintPropertyTreeBuilderContext&);
« no previous file with comments | « no previous file | third_party/WebKit/Source/core/paint/PaintPropertyTreeBuilder.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698